@@ -390,8 +390,13 @@ def ad_overture_discount(
         cookie,
         aadvid,
         timeout: int = 5,
-        timeout_retry: bool = True,
-        json_error_retry: bool = True
+        retry_delay: int = 1,  # 重试延时
+        retry_limit: int = -1,  # 重试次数限制，-1为无限制
+        return_json: bool = True,  # 是否返回json数据
+
+        ReadTimeout_retry: bool = True,  # 超时重试
+        JSONDecodeError_retry: bool = True,  # 返回非json类型重试
+        ConnectionError_retry: bool = True,  # 连接错误重试
 ):
     """
     【财务-活动与赠款-已获赠款】
@@ -415,15 +420,20 @@ def ad_overture_discount(
         "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.108 Safari/537.36",
         "x-requested-with": "XMLHttpRequest"
     }
-    response = my_requests.requests_json(
+    return my_requests.lazy_requests(
         method=method,
         url=url,
         headers=headers,
         timeout=timeout,
-        timeout_retry=timeout_retry,
-        json_error_retry=json_error_retry
+
+        retry_delay=retry_delay,
+        retry_limit=retry_limit,
+        return_json=return_json,
+
+        ReadTimeout_retry=ReadTimeout_retry,
+        JSONDecodeError_retry=JSONDecodeError_retry,
+        ConnectionError_retry=ConnectionError_retry
     )
-    return response.json()
 
 
 def notification_msg_list(
@@ -452,7 +462,7 @@ def notification_msg_list(
         "upgrade-insecure-requests": "1",
         "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:69.0) Gecko/20100101 Firefox/69.0",
     }
-    response = my_requests.lazy_requests(
+    return my_requests.lazy_requests(
         method=method,
         url=url,
         headers=headers,
@@ -465,5 +475,3 @@ def notification_msg_list(
         JSONDecodeError_retry=JSONDecodeError_retry,
         ConnectionError_retry=ConnectionError_retry
     )
-    return response
-
